Module: GeneValidatorApp::RunGeneValidator
- Extended by:
- Forwardable
- Defined in:
- lib/genevalidatorapp/genevalidator.rb
Overview
Module that runs GeneValidator
Defined Under Namespace
Classes: ArgumentError, RuntimeError
Class Attribute Summary collapse
-
.gv_dir ⇒ Object
readonly
Returns the value of attribute gv_dir.
-
.input_file ⇒ Object
readonly
Returns the value of attribute input_file.
-
.params ⇒ Object
readonly
Returns the value of attribute params.
-
.raw_seq ⇒ Object
readonly
Returns the value of attribute raw_seq.
-
.tmp_gv_dir ⇒ Object
readonly
Returns the value of attribute tmp_gv_dir.
-
.unique_id ⇒ Object
readonly
Returns the value of attribute unique_id.
-
.xml_file ⇒ Object
readonly
Returns the value of attribute xml_file.
Class Method Summary collapse
-
.init(url, params) ⇒ Object
Setting the scene.
-
.run ⇒ Object
Run BLAST(X/P), get_raw_sequence and genevalidator Returns html for just the table or a link to the page produced by GV.
Class Attribute Details
.gv_dir ⇒ Object (readonly)
Returns the value of attribute gv_dir.
30 31 32 |
# File 'lib/genevalidatorapp/genevalidator.rb', line 30 def gv_dir @gv_dir end |
.input_file ⇒ Object (readonly)
Returns the value of attribute input_file.
30 31 32 |
# File 'lib/genevalidatorapp/genevalidator.rb', line 30 def input_file @input_file end |
.params ⇒ Object (readonly)
Returns the value of attribute params.
30 31 32 |
# File 'lib/genevalidatorapp/genevalidator.rb', line 30 def params @params end |
.raw_seq ⇒ Object (readonly)
Returns the value of attribute raw_seq.
30 31 32 |
# File 'lib/genevalidatorapp/genevalidator.rb', line 30 def raw_seq @raw_seq end |
.tmp_gv_dir ⇒ Object (readonly)
Returns the value of attribute tmp_gv_dir.
30 31 32 |
# File 'lib/genevalidatorapp/genevalidator.rb', line 30 def tmp_gv_dir @tmp_gv_dir end |
.unique_id ⇒ Object (readonly)
Returns the value of attribute unique_id.
30 31 32 |
# File 'lib/genevalidatorapp/genevalidator.rb', line 30 def unique_id @unique_id end |
.xml_file ⇒ Object (readonly)
Returns the value of attribute xml_file.
30 31 32 |
# File 'lib/genevalidatorapp/genevalidator.rb', line 30 def xml_file @xml_file end |
Class Method Details
.init(url, params) ⇒ Object
Setting the scene
34 35 36 37 38 39 40 41 42 |
# File 'lib/genevalidatorapp/genevalidator.rb', line 34 def init(url, params) create_unique_id create_subdir_in_main_tmpdir create_soft_link_from_tmpdir_to_gv_dir @params = params validate_params obtain_db_path @url = produce_result_url_link(url) end |
.run ⇒ Object
Run BLAST(X/P), get_raw_sequence and genevalidator
Returns html for just the table or a link to the page produced by GV
46 47 48 49 50 51 52 |
# File 'lib/genevalidatorapp/genevalidator.rb', line 46 def run write_seq_to_file run_genevalidator copy_json_folder (@params[:result_link]) ? @url : output_json_file_path parse_output_json end |